==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/DateRangeDescriptorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DateRangeDescriptorDescription } from "./DateRangeDescriptorDescription";
/**
 * @hidden
 */
export let DateRangeDescriptorDescriptionMetadata = /*@__PURE__*/ (() => {
    class DateRangeDescriptorDescriptionMetadata extends Base {
        static b(a) {
            if (DateRangeDescriptorDescriptionMetadata.a == null) {
                DateRangeDescriptorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                DateRangeDescriptorDescriptionMetadata.c(DateRangeDescriptorDescriptionMetadata.a);
            }
            if (a.j(DateRangeDescriptorDescriptionMetadata.a)) {
                return;
            }
            a.y(DateRangeDescriptorDescriptionMetadata.a);
        }
        static c(a) {
            a.item("RangeType", "(wc:Type)ExportedType:string:DateRangeType");
            a.item("RangeType@names", "After;Before;Between;Specific;Weekdays;Weekends");
            a.item("DateRange", "Unknown");
        }
        static d(a) {
            DateRangeDescriptorDescriptionMetadata.b(a);
            a.aa("DateRangeDescriptor", () => new DateRangeDescriptorDescription());
            a.z("DateRangeDescriptor", DateRangeDescriptorDescriptionMetadata.a);
        }
    }
    DateRangeDescriptorDescriptionMetadata.$t = /*@__PURE__*/ markType(DateRangeDescriptorDescriptionMetadata, 'DateRangeDescriptorDescriptionMetadata');
    DateRangeDescriptorDescriptionMetadata.a = null;
    return DateRangeDescriptorDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/DateRangeDescriptorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DateRangeDescriptorDescription } from "./DateRangeDescriptorDescription";
/**
 * @hidden
 */
export let DateRangeDescriptorDescriptionMetadata = /*@__PURE__*/ (() => {
    class DateRangeDescriptorDescriptionMetadata extends Base {
        static b(a) {
            if (DateRangeDescriptorDescriptionMetadata.a == null) {
                DateRangeDescriptorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                DateRangeDescriptorDescriptionMetadata.c(DateRangeDescriptorDescriptionMetadata.a);
            }
            if (a.k(DateRangeDescriptorDescriptionMetadata.a)) {
                return;
            }
            a.aa(DateRangeDescriptorDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("RangeType", "(wc:Type)ExportedType:string:DateRangeType");
            a.item("RangeType@names", "After;Before;Between;Specific;Weekdays;Weekends");
            a.item("DateRange", "Unknown");
        }
        static d(a) {
            DateRangeDescriptorDescriptionMetadata.b(a);
            a.ac("DateRangeDescriptor", () => new DateRangeDescriptorDescription());
            a.ab("DateRangeDescriptor", DateRangeDescriptorDescriptionMetadata.a);
        }
    }
    DateRangeDescriptorDescriptionMetadata.$t = /*@__PURE__*/ markType(DateRangeDescriptorDescriptionMetadata, 'DateRangeDescriptorDescriptionMetadata');
    DateRangeDescriptorDescriptionMetadata.a = null;
    return DateRangeDescriptorDescriptionMetadata;
})();
